summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorMinh Nguyễn <mxn@1ec5.org>2015-08-26 14:05:57 -0700
committerMinh Nguyễn <mxn@1ec5.org>2015-08-27 11:06:17 -0700
commitbbca4ebed640ab4da4bd7eefdf57e4aaf1a0c673 (patch)
tree2c08b15d10021f323325d62f5326bb7708fdfea5 /include
parentbec1beb9b785b45498c90d6e40622783381ce77b (diff)
downloadqtlocation-mapboxgl-bbca4ebed640ab4da4bd7eefdf57e4aaf1a0c673.tar.gz
Pitch animation
Added pitch animation. Use util::clamp() instead of fmax() and fmin().
Diffstat (limited to 'include')
-rw-r--r--include/mbgl/ios/MGLMapView.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/include/mbgl/ios/MGLMapView.h b/include/mbgl/ios/MGLMapView.h
index 7aa3a4290f..46c923c409 100644
--- a/include/mbgl/ios/MGLMapView.h
+++ b/include/mbgl/ios/MGLMapView.h
@@ -187,13 +187,14 @@ IB_DESIGNABLE
/** The pitch of the map (measured in degrees).
*
* The default value `0` shows a completely flat map. Maximum value is `60`. */
-@property (nonatomic) double pitch;
+@property (nonatomic) CGFloat pitch;
/** Changes the pitch of the map.
- * @param pitch The pitch of the map (measured in degrees) relative to top-down.
- *
- * Changing the pitch tilts the map without changing the current center coordinate or zoom level. */
-- (void)setPitch:(double)pitch;
+* @param pitch The pitch of the map (measured in degrees) relative to top-down.
+* @param animated Specify `YES` if you want the map view to animate the change to the new pitch or `NO` if you want the map to display the new pitch immediately.
+*
+* Changing the pitch tilts the map without changing the current center coordinate or zoom level. */
+- (void)setPitch:(CGFloat)pitch animated:(BOOL)animated;
/** Resets the map pitch to head-on. */
- (IBAction)resetPitch;